from phonenumbers import region_code_for_number, parse


class PhoneNumber:
    def __init__(self, phone_number):
        self.number = phone_number
        parsed_number = parse(f'+{phone_number}')
        self.prefix = parsed_number.country_code
        self.country = region_code_for_number(parsed_number)



from urllib.parse import urlparse, parse_qs, unquote


def get_parameters(url: str) -> dict:
    dictionary = parse_qs(urlparse(unquote(url)).query)
    return {key: dictionary[key][0] if len(dictionary[key]) == 1 else dictionary[key] for key in dictionary.keys()}
